@@ -50,7 +50,7 @@ import java.util.Iterator;
  * {@link ts.tester.function.FunctionTester#setPrinter(ts.tester.function.print.Printer) setPrinter}\bhgčsB
  *
  * @author  V. 
- * @version $Revision: 1.2 $, $Date: 2007/02/16 16:12:49 $
+ * @version $Revision: 1.3 $, $Date: 2007/05/07 15:19:59 $
  */
 public class FunctionTester extends Tester
 {
@@ -70,6 +70,9 @@ public class FunctionTester extends Tester
   /** ݏ̎P[XʃIuWFNgB */
   private CaseResult inprocessingCaseResult_;
 
+  /** ̋@\sIuWFNg̈ꕔƂĎs邩ǂtOB */
+  private boolean isPart_ = false;
+
   /**
    * ftHgRXgN^B
    */
@@ -136,6 +139,30 @@ public class FunctionTester extends Tester
     return printerUsing_ ;
   }
 
+  /**
+   * ̃IuWFNgs@\̈ꕔƂĎs
+   * {@link ts.tester.function.FunctionTester FunctionTester}IuWFNg
+   * ǉB
+   * <br>
+   * k̏ꍇ͖B
+   *
+   * @param  tester {@link ts.tester.function.FunctionTester FunctionTester}
+   *           IuWFNgB
+   */
+  public void addPart(FunctionTester tester)
+  {
+    if (tester == null) {
+      return;
+    }
+
+    tester.isPart_ = true;
+    tester.printerUsing_ = this.printerUsing_ ;
+    tester.inprocessingCaseResult_ = this.inprocessingCaseResult_ ;
+    tester.rootCaseResult_ = this.rootCaseResult_ ;
+
+    super.addTester(tester);
+  }
+
   /**
    * ̒fwmFB
    * <br>
@@ -207,6 +234,10 @@ public class FunctionTester extends Tester
    */
   @Override protected final void initTesting()
   {
+    if (isPart_ ) {
+      return;
+    }
+
     printerUsing_ = getSpecifiedOrDefaultPrinter();
     inprocessingCaseResult_ = createRootCaseResult();
     rootCaseResult_ = inprocessingCaseResult_ ;
@@ -264,6 +295,10 @@ public class FunctionTester extends Tester
    */
   @Override protected void endTesting()
   {
+    if (isPart_) {
+      return;
+    }
+
     checkStopped();
 
     CaseResult current = inprocessingCaseResult_;
